@@ -20,6 +20,8 @@ import when from 'when';
 
 import { getNodesByIds } from '../selectors/nodes';
 import IronicApiErrorHandler from '../services/IronicApiErrorHandler';
+import IronicInspectorApiErrorHandler
+  from '../services/IronicInspectorApiErrorHandler';
 import IronicApiService from '../services/IronicApiService';
 import IronicInspectorApiService from '../services/IronicInspectorApiService';
 import MistralApiService from '../services/MistralApiService';
@@ -119,6 +121,40 @@ export default {
     };
   },
 
+  fetchNodeIntrospectionDataSuccess(nodeId, data) {
+    return {
+      type: NodesConstants.FETCH_NODE_INTROSPECTION_DATA_SUCCESS,
+      payload: { nodeId, data }
+    };
+  },
+
+  fetchNodeIntrospectionDataFailed(nodeId) {
+    return {
+      type: NodesConstants.FETCH_NODE_INTROSPECTION_DATA_FAILED,
+      payload: nodeId
+    };
+  },
+
+  fetchNodeIntrospectionData(nodeId) {
+    return dispatch => {
+      IronicInspectorApiService.getIntrospectionData(nodeId)
+        .then(response => {
+          dispatch(this.fetchNodeIntrospectionDataSuccess(nodeId, response));
+        })
+        .catch(error => {
+          dispatch(this.fetchNodeIntrospectionDataFailed(nodeId));
+          logger.error(
+            'Error in NodesActions.fetchNodeIntrospectionData',
+            error.stack || error
+          );
+          let errorHandler = new IronicInspectorApiErrorHandler(error);
+          errorHandler.errors.forEach(error => {
+            dispatch(NotificationActions.notify(error));
+          });
+        });
+    };
+  },
+
   /*
    * Poll fetchNodes until no node is in progress
    */
@@ -188,13 +224,16 @@ export default {
           break;
         }
         case 'FAILED': {
+          let message = messagePayload.message
+            .map(msg => msg.message)
+            .join(', ');
           dispatch(
             NotificationActions.notify({
               type: 'error',
               title: formatMessage(
                 messages.introspectionFailedNotificationTitle
               ),
-              message: messagePayload.message.join(', ')
+              message
             })
           );
           break;
@@ -296,6 +335,73 @@ export default {
     };
   },
 
+  startManageNodes(nodeIds) {
+    return (dispatch, getState) => {
+      dispatch(this.startOperation(nodeIds));
+      dispatch(this.pollNodeslistDuringProgress());
+      MistralApiService.runWorkflow(MistralConstants.BAREMETAL_MANAGE, {
+        node_uuids: nodeIds
+      })
+        .then(response => {
+          if (response.state === 'ERROR') {
+            dispatch(
+              NotificationActions.notify({
+                title: 'Error',
+                message: response.state_info
+              })
+            );
+            dispatch(this.finishOperation(nodeIds));
+          }
+        })
+        .catch(error => {
+          logger.error(
+            'Error in NodesActions.startManageNodes',
+            error.stack || error
+          );
+          let errorHandler = new MistralApiErrorHandler(error);
+          errorHandler.errors.forEach(error => {
+            dispatch(NotificationActions.notify(error));
+          });
+          dispatch(this.finishOperation(nodeIds));
+        });
+    };
+  },
+
+  manageNodesFinished(messagePayload) {
+    return (dispatch, getState) => {
+      const nodeIds = messagePayload.execution.input.node_uuids;
+      dispatch(this.finishOperation(nodeIds));
+      dispatch(this.fetchNodes());
+
+      switch (messagePayload.status) {
+        case 'SUCCESS': {
+          dispatch(
+            NotificationActions.notify({
+              type: 'success',
+              title: 'Nodes are manageable',
+              message: messagePayload.message
+            })
+          );
+          break;
+        }
+        case 'FAILED': {
+          messagePayload.message.map(message => {
+            dispatch(
+              NotificationActions.notify({
+                type: 'error',
+                title: 'Error',
+                message: message.result
+              })
+            );
+          });
+          break;
+        }
+        default:
+          break;
+      }
+    };
+  },
+
   updateNode(nodePatch) {
     return (dispatch, getState) => {
       dispatch(this.updateNodePending(nodePatch.uuid));
